@@ -144,6 +144,7 @@ class GroupOptionsSerializer(DynamicModelSerializer):
     class Meta:
         model = GroupOptions
         fields = '__all__'
+        read_only_fields = ('is_admin')
 
 
 class CUserSerializer(serializers.ModelSerializer):
@@ -178,6 +179,10 @@ class CUserSerializer(serializers.ModelSerializer):
             user.is_staff = False
         else:
             user.is_staff = True
+        if group_id == "1":
+            user.is_admin = True
+        else:
+            user.is_admin = False
         user.set_password(validated_data['password'])
         user.groups.add(group_id)
         user.save()
