@@ -1,5 +1,5 @@
 # from rest_framework import routers
-from .views import InvitationViewSet, accept_invitation, UserViewSet, GroupViewSet, PermissionViewSet, ContenttypeViewSet, GroupOptionsViewSet, CUserViewSet, CGroupViewSet
+from .views import InvitationViewSet, accept_invitation, UserViewSet, GroupViewSet, PermissionViewSet, ContenttypeViewSet, GroupOptionsViewSet, CUserViewSet, CGroupViewSet, signup
 from django.conf.urls import include, url
 from xtrm_drest.routers import DynamicRouter
 
@@ -17,11 +17,18 @@ invitations_patterns = (
     [
         url(
             r'^{0}/{1}/(?P<key>\w+)/?$'.format(
-                'invitations','accept-invite'
+                'invitations', 'verify'
             ),
             accept_invitation,
             name='accept-invite'
         ),
+        url(
+            r'^{0}/{1}/(?P<key>\w+)/?$'.format(
+                'invitations', 'signup'
+            ),
+            signup,
+            name='signup-invite'
+        ),
     ],
     'invitations'
 )
