@@ -18,6 +18,7 @@ from rest_auth.views import LoginView as RestAuthLoginView
 from django.conf import Settings, settings
 from .utils import get_author_model
 from django.db.models.functions import Concat
+from django.db.models import Q
 
 AuthorModel = get_author_model()
 
@@ -112,7 +113,7 @@ class UserViewSet(xViewSet):
 
 class GroupViewSet(xViewSet):
     #http_method_names = [m for m in viewsets.ModelViewSet.#http_method_names if m not in [m for m in viewsets.ModelViewSet.#http_method_names if m not in ['get']]]
-    queryset = Group.objects.all() if HAS_GUEST_PERMISSION else Group.objects.filter(id!=2)
+    queryset = Group.objects.all() if HAS_GUEST_PERMISSION else Group.objects.filter(~Q(id=2))
     serializer_class = GroupSerializer
     reporttitle = 'Groups'
     #orientation='landscape'
